Summary:	Versatile Database Driven Nameserver
Name:		pdns
Version:	4.1.0
Release:	%mkrel 1
License:	GPLv2
Group:		System/Servers
URL:		http://www.powerdns.com/
Source0:	http://downloads.powerdns.com/releases/%{name}-%{version}.tar.bz2
Source10:	README.urpmi
Requires(post): systemd >= %{systemd_required_version}
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	mysql-devel
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	libstdc++-devel
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	postgresql-devel
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(lua)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	polarssl-devel
BuildRequires:	pkgconfig(geoip)
BuildRequires:	pkgconfig(yaml-cpp)
BuildRequires:	pkgconfig(systemd)
BuildRequires:	pkgconfig(libsodium)
BuildRequires:	pkgconfig(protobuf)
#BuildRequires:	ragel asciidoc xmlto <- needed for git snapshots
#BuildRequires:	docbook-utils-pdf
Provides:	nameserver powerdns PowerDNS
Obsoletes:	nameserver powerdns PowerDNS

%description
PowerDNS is a versatile nameserver which supports a large number
of different backends ranging from simple zonefiles to relational
databases and load balancing/failover algorithms.

It comes with support for MySQL, PostgreSQL, Bind zonefiles and the 'pipe
backend' availible as external packages.

%package	backend-pipe
Summary:	Pipe/coprocess backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-pipe
Obsoletes:	PowerDNS-backend-pipe
Requires:	%{name} = %{version}

%description	backend-pipe
This package contains the pipe backend for the PowerDNS nameserver. This
allows PowerDNS to retrieve domain info from a process that accepts
questions on stdin and returns answers on stdout. 

%package	backend-mysql
Summary:	MySQL backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-mysql
Obsoletes:	PowerDNS-backend-mysql
Requires:	%{name} = %{version}

%description	backend-mysql
This package contains a MySQL backend for the PowerDNS nameserver.

%package	backend-pgsql
Summary:	Generic PostgreSQL backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-pgsql
Obsoletes:	PowerDNS-backend-pgsql
Requires:	%{name} = %{version}

%description	backend-pgsql
This package contains a generic PostgreSQL backend 
for the PowerDNS nameserver. It has configurable SQL statements.

%package	backend-ldap
Summary:	LDAP backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-ldap
Obsoletes:	PowerDNS-backend-ldap
Requires:	%{name} = %{version}

%description	backend-ldap
This package contains a LDAP backend for the PowerDNS nameserver.

%package	backend-sqlite
Summary:	SQLite backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-sqlite
Obsoletes:	PowerDNS-backend-sqlite
Requires:	%{name} = %{version}

%description	backend-sqlite
This package contains a SQLite backend for the PowerDNS nameserver.

%package	backend-geoip
Summary:	GeoIP backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-geoip
Obsoletes:	PowerDNS-backend-geo
Requires:	%{name} = %{version}

%description	backend-geoip
This package contains a GeoIP backend for the PowerDNS nameserver.

%prep
%setup -q -n pdns-%{version}

%build
#autoreconf -fi; automake --add-missing <- needed for git snapshots

%configure2_5x \
    --disable-static \
    --enable-tools \
    --enable-libsodium \
    --enable-systemd \
    --enable-unit-tests \
    --enable-reproducible \
    --with-sqlite3 \
    --with-system-polarssl \
    --sysconfdir=%{_sysconfdir}/powerdns \
    --libdir=%{_libdir} \
    --with-socketdir=/run/powerdns \
    --with-modules="bind" \
    --with-dynmodules="gmysql gpgsql pipe ldap gsqlite3 geoip" \
    --with-mysql-lib=%{_libdir} \
    --with-pgsql-lib=%{_libdir}

%make_build

%check

%make_build -C pdns check

%install

%make_install

find %{buildroot} -name '*.la' -delete

# fix the config
mv %{buildroot}%{_sysconfdir}/powerdns/pdns.conf-dist %{buildroot}%{_sysconfdir}/powerdns/pdns.conf

cat >> %{buildroot}%{_sysconfdir}/powerdns/pdns.conf << EOF
include-dir=%{_sysconfdir}/powerdns/conf.d
module-dir=%{_libdir}/pdns
socket-dir=/run/powerdns
setuid=powerdns
setgid=powerdns
launch=bind
EOF

chmod 600 %{buildroot}%{_sysconfdir}/powerdns/pdns.conf

install -d %{buildroot}%{_sysconfdir}/powerdns/conf.d

# fix per backend config files
for i in geoip gmysql gpgsql gsqlite3 ldap pipe; do
    echo "# backend config for %{_libdir}/powerdns/lib${i}backend.so" > %{buildroot}%{_sysconfdir}/powerdns/conf.d/lib${i}backend.conf
done

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/powerdns 0755 root powerdns
EOF

cp %{SOURCE10} README.urpmi

%pre
%_pre_useradd powerdns /var/lib/powerdns /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel powerdns

%files
#%doc INSTALL README rtfm.powerdns.com
%doc INSTALL README README.urpmi
%doc %{_docdir}/%{name}/*.sql
%doc %{_docdir}/%{name}/*.schema
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/pdns.conf
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/pdns.service
%{_unitdir}/pdns@.service
%dir %{_sysconfdir}/powerdns
%dir %{_sysconfdir}/powerdns/conf.d
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libbindbackend.so
%{_bindir}/calidns
%{_bindir}/dnsbulktest
%{_bindir}/dnsgram
%{_bindir}/dnspcap2protobuf
%{_bindir}/dnsreplay
%{_bindir}/dnsscan
%{_bindir}/dnsscope
%{_bindir}/dnstcpbench
%{_bindir}/dnswasher
%{_bindir}/dumresp
%{_bindir}/ixplore
%{_bindir}/nproxy
%{_bindir}/nsec3dig
%{_bindir}/pdns_control
%{_bindir}/pdns_notify
%{_bindir}/pdnsutil
%{_bindir}/saxfr
%{_bindir}/sdig
%{_bindir}/stubquery
%{_bindir}/zone2json
%{_bindir}/zone2ldap
%{_bindir}/zone2sql
%{_sbindir}/pdns_server
%{_mandir}/man1/calidns.1*
%{_mandir}/man1/dnsbulktest.1*
%{_mandir}/man1/dnsgram.1*
%{_mandir}/man1/dnspcap2protobuf.1*
%{_mandir}/man1/dnsreplay.1*
%{_mandir}/man1/dnsscan.1*
%{_mandir}/man1/dnsscope.1*
%{_mandir}/man1/dnstcpbench.1*
%{_mandir}/man1/dnswasher.1*
%{_mandir}/man1/dumresp.1*
%{_mandir}/man1/ixplore.1*
%{_mandir}/man1/nproxy.1*
%{_mandir}/man1/nsec3dig.1*
%{_mandir}/man1/pdns_control.1*
%{_mandir}/man1/pdns_notify.1*
%{_mandir}/man1/pdns_server.1*
%{_mandir}/man1/pdnsutil.1*
%{_mandir}/man1/saxfr.1*
%{_mandir}/man1/sdig.1*
%{_mandir}/man1/zone2json.1*
%{_mandir}/man1/zone2ldap.1*
%{_mandir}/man1/zone2sql.1*

%files backend-pipe
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libpipebackend.conf
%{_libdir}/%{name}/libpipebackend.so

%files backend-mysql
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgmysqlbackend.conf
%{_libdir}/%{name}/libgmysqlbackend.so

%files backend-pgsql
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgpgsqlbackend.conf
%{_libdir}/%{name}/libgpgsqlbackend.so

%files backend-ldap
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libldapbackend.conf
%{_libdir}/%{name}/libldapbackend.so

%files backend-sqlite
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgsqlite3backend.conf
%{_libdir}/%{name}/libgsqlite3backend.so

%files backend-geoip
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgeoipbackend.conf
%{_libdir}/%{name}/libgeoipbackend.so


%changelog
* Mon Dec 04 2017 mitya <mitya> 4.1.0-1.mga6
+ Revision: 1181283
- New version 4.1.0
- New version 4.0.5
- PowerDNS for Mageia 6

* Sat Nov 18 2017 mitya <mitya> 4.0.4-1.mga7
+ Revision: 1177688
- New version 4.0.4
- Enable BIND backend
- Enable protobuf and libsodium
- Enable unit tests
- Use stock systemd unit file
- Tweak runtime dir perms, see https://github.com/PowerDNS/pdns/issues/4826
- Revive pdns

  + akien <akien>
    - Packaged was removed from cauldron, obsolete

* Fri Sep 09 2016 luigiwalser <luigiwalser> 3.4.10-1.mga6
+ Revision: 1051020
- 3.4.10 (fixes CVE-2016-5426 and CVE-2016-5427)
- remove upstreamed CVE-2016-6172 patch

* Wed Aug 10 2016 luigiwalser <luigiwalser> 3.4.9-1.mga6
+ Revision: 1045370
- 3.4.9

* Tue Aug 09 2016 luigiwalser <luigiwalser> 3.4.8-2.mga6
+ Revision: 1045187
- add upstream patch to fix CVE-2016-6172

* Sun Feb 28 2016 oden <oden> 3.4.8-1.mga6
+ Revision: 980324
- 3.4.8

* Thu Jan 14 2016 luigiwalser <luigiwalser> 3.4.7-4.mga6
+ Revision: 923148
- rebuild for polarssl/mbedtls

* Mon Dec 28 2015 daviddavid <daviddavid> 3.4.7-3.mga6
+ Revision: 916355
- rebuild for new boost 1.60.0

* Fri Nov 06 2015 luigiwalser <luigiwalser> 3.4.7-1.mga6
+ Revision: 898068
- 3.4.7

* Tue Oct 20 2015 danf <danf> 3.4.6-1.mga6
+ Revision: 892945
- Fixed build of new version
- Moved backend modules to the standard upstream location

  + tv <tv>
    - drop merged patch
    - new release
    - rebuild for new boost

  + fwang <fwang>
    - rebuild for new boost

* Sun Aug 02 2015 daviddavid <daviddavid> 3.3.3-2.mga6
+ Revision: 860600
- rebuild for new boost-1.58.0

* Tue Jul 07 2015 luigiwalser <luigiwalser> 3.3.3-1.mga6
+ Revision: 852340
- 3.3.3

* Fri May 01 2015 luigiwalser <luigiwalser> 3.3.2-1.mga5
+ Revision: 820959
- 3.3.2 (fixes CVE-2015-1868)

  + oden <oden>
    - P1: security fix for CVE-2015-1868

* Tue Nov 25 2014 cjw <cjw> 3.3.1-11.mga5
+ Revision: 799086
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 3.3.1-10.mga5
+ Revision: 747066
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.3.1-9.mga5
+ Revision: 683391
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 oden <oden> 3.3.1-8.mga5
+ Revision: 658550
- submitted to the correct repo

* Thu Jul 31 2014 oden <oden> 3.3.1-7.mga5
+ Revision: 658538
- rebuilt against new polarssl libs

* Sun Jun 29 2014 tv <tv> 3.3.1-6.mga5
+ Revision: 641013
- rebuild with lua-5.2

* Thu Jun 12 2014 oden <oden> 3.3.1-5.mga5
+ Revision: 635769
- P0: fix a DoS (http://blog.powerdns.com/2014/02/06/related-to-recent-dos-attacks-recursor-configuration-file-guidance/)

* Sat Feb 08 2014 oden <oden> 3.3.1-4.mga5
+ Revision: 585844
- rebuilt for polarssl-1.3.4

* Tue Feb 04 2014 oden <oden> 3.3.1-3.mga5
+ Revision: 580921
- rebuild

* Sun Feb 02 2014 oden <oden> 3.3.1-2.2.mga4
+ Revision: 568628
- fix build

* Wed Nov 27 2013 oden <oden> 3.3.1-2.mga4
+ Revision: 553761
- fix rpm scripts

* Sat Oct 19 2013 umeabot <umeabot> 3.3.1-1.1.mga4
+ Revision: 529551
- Mageia 4 Mass Rebuild

  + oden <oden>
    - 3.3.1 (git snapshot)
    - rebuilt against libpolarssl.so.4

* Wed Jul 10 2013 oden <oden> 3.3-2.mga4
+ Revision: 452452
- enable better per backend config

* Mon Jul 08 2013 oden <oden> 3.3-1.mga4
+ Revision: 451431
- 3.3

* Sat May 04 2013 oden <oden> 3.2-4.mga3
+ Revision: 412337
- break out the recursor due to security issues

* Wed Apr 10 2013 malo <malo> 3.2-3.mga3
+ Revision: 409471
- rebuild for boost 1.53

* Sun Mar 24 2013 colin <colin> 3.2-2.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Thu Feb 21 2013 barjac <barjac> 3.2-1.mga3
+ Revision: 399622
- patch for autotools-1.13
- add pdns-recursor.conf to files

  + oden <oden>
    - 3.2
    - merged the pdns-recursor spec file and provide it from this source rpm package
    - fix build for system polarssl libs
    - newer S1
    - various fixes

* Sun Jan 13 2013 luigiwalser <luigiwalser> 3.1-4.mga3
+ Revision: 364974
- add tmpfiles config for /run/powerdns

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 3.1-2.mga3
+ Revision: 333057
- rebuild for new boost

* Thu Nov 15 2012 fwang <fwang> 3.1-1.mga3
+ Revision: 318162
- update install script
- use systemd
- update file list
- build sqlite3 ext
- drop patch
- new version 3.1

* Wed Aug 01 2012 fwang <fwang> 3.0.1-3.mga3
+ Revision: 276898
- build with lua 5.1
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 3.0.1-2.mga3
+ Revision: 250109
- rebuild for new boost

* Fri Jan 13 2012 fwang <fwang> 3.0.1-1.mga2
+ Revision: 195555
- new version 3.0.1

* Sun Dec 11 2011 fwang <fwang> 3.0-1.mga2
+ Revision: 180569
- drop with lua specification
- br lua
- new version 3.0

* Wed Dec 07 2011 fwang <fwang> 2.9.22-10.mga2
+ Revision: 178113
- drop .la files

* Thu Mar 24 2011 dmorgan <dmorgan> 2.9.22-9.mga1
+ Revision: 77114
- Rebuild against new mysql

* Sun Feb 20 2011 dmorgan <dmorgan> 2.9.22-8.mga1
+ Revision: 54557
- imported package pdns

